@@ -13,6 +13,14 @@ class Club:
     token = None
     client_id = None
     client_secret = None
+    ERRORS = {
+        400: "Bad Request: Unable to pass parameters",
+        401: "Unauthorized: Access token was missing or incorrect",
+        403: "Forbidden: Accessing restricted area without appropriate user privileges",
+        404: "Not Found: The URI requested is invalid or the resource requested, such as a contact, does not exists.",
+        406: "Not Acceptable: Returned when an invalid format is specified in the request.",
+        422: "Unprocessable Entity: Sending invalid fields will result in an unprocessable entity response.",
+    }
     
     def __init__(self, slug, client_id, client_secret):
         """
@@ -131,13 +139,15 @@ class Club:
                 # One of TidyClub's documented error codes has been caught (as opposed to a positive response).
                 # Attempt to get more information by checking if any JSON error data has been provided.
                 # If not, fall back to a hard-coded set of error codes/descriptions, as provided in the TidyClub API docs.
-                error_json = json.loads(e.read())
-                if 'error' in error_json and 'error_description' in error_json:
+                
+                try:
+                    error_json = json.loads(e.read())
                     tc_error = error_json['error']
                     tc_error_desc = error_json['error_description']
-                else:
+                except ValueError as v:
                     tc_error = e.code
                     tc_error_desc = self.ERRORS[e.code]
+                
                 raise PyTCUpstreamError(tc_error, tc_error_desc)
             else:
                 # If the error isn't documented, pass the raw HTTPError up.
